@@ -1,5 +1,5 @@
 package Amazon::DynamoDB::20120810;
-$Amazon::DynamoDB::20120810::VERSION = '0.31';
+$Amazon::DynamoDB::20120810::VERSION = '0.32';
 use strict;
 use warnings;
 
@@ -728,12 +728,15 @@ method _process_request(HTTP::Request $req, CodeRef $done?) {
                 fail => sub {
                     my ($status, $resp, $req)= @_;
                     my $r;
-                    if (defined($resp)) {
+                    if (defined($resp) && defined($resp->code)) {
                         if ($resp->code == 500) {
                             $do_retry = 1;
                             $current_retry++;
                         } elsif ($resp->code == 400) {
-                            $r = decode_json($resp->decoded_content);
+                            my $json = $resp->can('decoded_content')
+                                ? $resp->decoded_content
+                                : $resp->body; # Mojo
+                            $r = decode_json($json);
                             if ($r->{__type} =~ /ProvisionedThroughputExceededException$/) {
                                 # Need to sleep
                                 $do_retry = 1;
@@ -1006,7 +1009,7 @@ Amazon::DynamoDB::20120810
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 DESCRIPTION
 
